/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.config.model;


import at.jku.fim.rubanetra.pcap.PcapActivityListener;
import at.jku.fim.rubanetra.pcap.PcapHandler;
import at.jku.fim.rubanetra.protocol.mapper.KrakenTransportLayerMappingFactory;

/**
 * Generic specification of a Kraken application protocol configuration builder.
 */
public interface KrakenProtocolConfigurationBuilder {
    /**
     * Builds the protocol configuration that has been set up until now
     * @return the immutable protocol configuration that has been set up until now
     */
    public abstract KrakenProtocolConfiguration buildProtocolConfiguration();

    /**
     * Set a transport layer filter for the parser of this protocol
     * @param transportProtocolPortSpec the port specification for this application layer protocol parser
     * @return the builder instance
     * @see at.jku.fim.rubanetra.config.model.KrakenProtocolConfiguration
     */
    public abstract KrakenProtocolConfigurationBuilder setPortSpecification(PortSpecification transportProtocolPortSpec);

    /**
     * Set the transport layer mapping strategy to use for this protocol
     * @param strategy the {@link at.jku.fim.rubanetra.protocol.mapper.TransportLayerMappingStrategy} to use
     * @return the builder instance
     * @see at.jku.fim.rubanetra.protocol.mapper.KrakenTransportLayerMappingFactory
     */
    public abstract KrakenProtocolConfigurationBuilder setTransportProtocolMappingStrategy(String strategy);

    /**
     * Set the transport layer mapping factory to use for building transport layer mapping strategies
     * @param mappingFactory the transport layer mapping factory to use
     * @return the builder instance
     */
    public abstract KrakenProtocolConfigurationBuilder setTransportProtocolMappingFactory(KrakenTransportLayerMappingFactory mappingFactory);

    /**
     * Set the pcap packet input stream for this application layer protocol parser
     * @param pcapHandler the Pcap packet input stream
     * @return the builder instance
     */
    public abstract KrakenProtocolConfigurationBuilder setPcapHandler(PcapHandler<PcapActivityListener> pcapHandler);

    /**
     * Resets all settings of the current protocol configuration
     */
    public abstract void resetCurrentProtocolConfiguration();

    /**
     * Bind a protocol handler to another protocol handler, i.e. define the stream of decoded data
     * (in general one way only, unless bound vice-versa as well)
     * @param bindFrom the wild protocol identifier which can be mapped by the protocol registry to
     *                 an existing protocol handler, and that will be bound to the handler of the bindTo protocol
     * @param bindTo the wild protocol identifier which can be mapped by the protocol registry to
     *               an existing protocol handler, and that will receive decoded data from the bindFrom handler
     *
     * @return the builder instance
     */
    public abstract KrakenProtocolConfigurationBuilder bindProtocol(String bindFrom, String bindTo);

    /**
     * Set the protocol identifier to use for this protocol configuration.
     * @param currentProtocolIdentifier a protocol identifier (should be unique within this framework)
     * @return the builder instance
     */
    public abstract KrakenProtocolConfigurationBuilder setCurrentProtocolIdentifier(String currentProtocolIdentifier);
}