/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.config.model;


/**
 * This interface represents a meta-identifier for network protocols of arbitrary layers and frameworks.
 * Since the currently included network stack parser/decoder (Kraken/JNetPcap) use their own, partly incompatible
 * protocol identifier mechanism, this interface tries to provide a common denominator which allows the identification
 * of a single network protocol within the system's framework.
 * The provided information of implementations is intended for internal usage only, i.e. the used identifiers are
 * neither globally unique nor adhere to a specific standard/RFC.
 * See {@link at.jku.fim.rubanetra.config.model.KrakenApplicationProtocolId} and
 * {@link at.jku.fim.rubanetra.config.model.JNetPcapProtocolId}.
 */
public interface ProtocolId {

    /**
     * @return a unique identifier (within the framework) for the network protocol to represent
     */
    public abstract String getProtocolId();

    /**
     * @return a human-readable name for the network protocol to represent
     */
    public abstract String getName();
}
