/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.output;

import org.apache.commons.csv.CSVPrinter;

import java.io.IOException;

/**
 * This interface should be implemented by all {@link at.jku.fim.rubanetra.protocol.activity.Activity} implementations
 * that can provide their data in a comma separated fashion.
 */
public interface CsvRecordOutputWriter {
    /**
     * Write a single record, i.e. one line, using the provided csvPrinter to the output stream.
     *
     * @param csvPrinter An initialized csvPrinter, shared among all activities
     * @throws IOException If it is not possible to write to the output stream or the printer reached an invalid state.
     */
    public void writeCsvRecord(CSVPrinter csvPrinter) throws IOException;
}
