/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.output;


import at.jku.fim.rubanetra.protocol.activity.Activity;

import java.io.IOException;

/**
 * Defines methods for writing {@link at.jku.fim.rubanetra.protocol.activity.Activity} to a provided
 * output-stream. Implementations of this interface represent the transformation to apply to the passed activties
 * before they are written out.
 */
public interface OutputWriterStrategy {
    /**
     * Write an {@link at.jku.fim.rubanetra.protocol.activity.Activity} to the provided output-stream
     * using the implementation-specific transformation of the content.
     *
     * @param activity the activity that will be transformed according to the strategy in use and written to the
     *                 provided output-stream
     */
    public void writeActivity(Activity activity);

    /**
     * Closes the writer but does not release or close the underlying output stream.
     * If the writer is already closed then invoking this
     * method has no effect.
     */
    public void closeWriter() throws IOException;
}
