/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.output.impl;

import at.jku.fim.rubanetra.output.CsvRecordOutputWriter;
import at.jku.fim.rubanetra.output.OutputWriterStrategy;
import at.jku.fim.rubanetra.protocol.activity.Activity;
import org.apache.commons.csv.CSVFormat;
import org.apache.commons.csv.CSVPrinter;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.BufferedWriter;
import java.io.IOException;
import java.io.OutputStream;
import java.io.OutputStreamWriter;

/**
 * Created by stefan on 9/30/14.
 */
public class CsvOutputWriterStrategy implements OutputWriterStrategy {
    private final Logger log = LoggerFactory.getLogger(getClass());
    private final CSVPrinter csvPrinter;

    public CsvOutputWriterStrategy(OutputStream outputStream) throws IOException {
        if (outputStream == null) {
            log.error("Cannot write to passed outputstream - null pointer");
            throw new NullPointerException();
        }

        this.csvPrinter = new CSVPrinter(new BufferedWriter(new OutputStreamWriter(outputStream)), CSVFormat.RFC4180);
    }

    /**
     * Write an {@link at.jku.fim.rubanetra.protocol.activity.Activity} to the provided output-stream
     * using the implementation-specific transformation of the content.
     *
     * @param activity the activity that will be transformed according to the strategy in use and written to the
     *                 provided output-stream
     */
    @Override
    public void writeActivity(Activity activity) {
        if (activity == null) {
            log.warn("Skipping activity - null pointer");
            return;
        }
        if (CsvRecordOutputWriter.class.isAssignableFrom(activity.getClass())) {
            try {
                ((CsvRecordOutputWriter) activity).writeCsvRecord(csvPrinter);
            } catch (IOException e) {
                e.printStackTrace();
                log.warn("Unable to serialize activity {} to the outputstream, skipping.", activity.getCompoundFrameNumbers());
                log.debug("Exception:", e);
            }
        } else {
            log.warn("Skipping activity - CSVRecordOutputWriter interface is not implemented by class {}", activity.getClass());
        }
    }

    /**
     * Closes the writer but does not release or close the underlying output stream.
     * If the writer is already closed then invoking this
     * method has no effect.
     */
    @Override
    public void closeWriter() throws IOException {
        csvPrinter.flush();
        csvPrinter.close();
    }
}
