/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.pcap;

/**
 * Represent an intermediary between the native Berkeley Packet Filter compiler and this project external interface.
 * It is intended as a mere encapsulation of required and optional parameters before passing it as raw values to
 * the JNetPcap engine for native compilation. Error/Syntax checks will not be performed by this class.
 */
public class PcapFilter {
    private final String bpfExpression;
    private final boolean optimize;
    private final int netmask;

    /**
     * Default constructor
     *
     * @param bpfExpression a Berkeley Packet Filter expression, may be null or empty
     * @param optimize      whether or not to try to optimize the provided filter expression.
     * @param netmask       an integer representing a network mask that will be applied by the native compiler.
     */
    public PcapFilter(String bpfExpression, boolean optimize, int netmask) {
        this.bpfExpression = bpfExpression;
        this.optimize = optimize;
        this.netmask = netmask;
    }

    /**
     * @return a Berkeley Packet Filter expression, may be null or empty
     */
    public String getBpfExpression() {
        return bpfExpression;
    }

    /**
     * JNetPcap expects an integer value, where 0 is equal to false.
     *
     * @return whether or not to try to optimize the provided filter expression.
     */
    public boolean isOptimize() {
        return optimize;
    }

    /**
     * @return an integer representing a network mask that will be applied by the native compiler.
     */
    public int getNetmask() {
        return netmask;
    }

}
