/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.activity;


/**
 * Extension of {@link at.jku.fim.rubanetra.protocol.activity.AbstractActivity}, added abstraction of
 * a {@link at.jku.fim.rubanetra.protocol.activity.ReplaceableActivity}, i.e. implementations may
 * replace another activity in addition to a mere extension.
 */
public abstract class AbstractReplaceableActivity extends AbstractActivity implements ReplaceableActivity {
    private static final long serialVersionUID = 3930231956209393878L;
    private boolean replaced;

    /**
     * Constructs a prototypical Event.
     *
     * @param source The object on which the Event initially occurred.
     * @throws IllegalArgumentException if source is null.
     */
    public AbstractReplaceableActivity(Object source) {
        super(source);
    }

    @Override
    public boolean isReplaced() {
        return replaced;
    }

    @Override
    public void setReplaced(boolean isReplaced) {
        replaced = isReplaced;
    }

    public void replaceActivity(ReplaceableActivity activity) {
        activity.setReplaced(true);
        extendActivity(activity);
    }
}
