/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.activity;


import java.util.UUID;

/**
 * This class serves as the base class for custom class extension inside the Drools rules files, i.e. any declared
 * classes using the Drools rule language may extend this class in order to qualify as valid Activity which
 * is ultimately supposed to be written to the final OutputStream.
 * As soon as it is possible to extend an abstract class (e.g. the AbstractActivity or the AbstractReplaceableActivity)
 * inside the Drools rule definition this class can be considered obsolete. However, currently it appears that
 * the base class requires a default constructor. This class defines a default constructor, however, the source
 * object is currently substituted by a random UUID.
 */
public class DroolsBaseActivity extends AbstractReplaceableActivity {
    private static final long serialVersionUID = -5807104716376365130L;

    /**
     * Constructs a prototypical Event.
     *
     * @param source The object on which the Event initially occurred.
     * @throws IllegalArgumentException if source is null.
     */
    public DroolsBaseActivity(Object source) {
        super(source);
    }

    public DroolsBaseActivity() {
        super(UUID.randomUUID());
    }
}
