/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.activity;


import java.io.Serializable;

/**
 * An optional field consists of an identifier and an arbitrary value and may be added to the final OutputStream.
 */
public class OptionalField implements Serializable {
    private static final long serialVersionUID = -6391001123309282371L;
    private String identifier;
    private Object value;

    /**
     * Default constructor, all values are initialized as null pointers.
     */
    public OptionalField() {
        this.identifier = null;
        this.value = null;
    }

    /**
     * Construct a new optional field
     * @param identifier the unique identifier among all optional field to be included for a single activity-
     * @param value an arbitrary object
     */
    public OptionalField(String identifier, Object value) {
        this.identifier = identifier;
        this.value = value;
    }

    public Object getValue() {
        return value;
    }

    public void setValue(Object value) {
        this.value = value;
    }

    public String getIdentifier() {
        return identifier;
    }

    public void setIdentifier(String identifier) {
        this.identifier = identifier;
    }
}
