/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.activity;

import java.io.Serializable;
import java.util.EventObject;

/**
 * This event may be fired by any custom rule definition and it directs the output handler to write an Activity to
 * the output stream.
 */
public class OutputActivityEvent extends EventObject implements Serializable {
    private static final long serialVersionUID = -4878319387952597370L;
    private final Activity toOutput;

    /**
     * Constructs a prototypical Event.
     *
     * @param toOutput The activity that should be written to the output stream.
     * @throws IllegalArgumentException if source is null.
     */
    public OutputActivityEvent(Activity toOutput) {
        super(toOutput);

        this.toOutput = toOutput;
    }

    public Activity getToOutput() {
        return toOutput;
    }
}
