/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.activity.dhcp;

import at.jku.fim.rubanetra.pcap.PcapActivity;
import at.jku.fim.rubanetra.protocol.activity.AbstractReplaceableActivity;
import org.kie.api.definition.type.Role;
import org.krakenapps.pcap.decoder.dhcp.DhcpMessage;

/**
 * An encapsulation of a {@link org.krakenapps.pcap.decoder.dhcp.DhcpMessage}.
 */
@Role(Role.Type.EVENT)
public class DhcpActivity extends AbstractReplaceableActivity {
    private static final long serialVersionUID = -3031909630697934242L;
    private final PcapActivity pcapActivity;
    private final DhcpMessage dhcpMessage;

    /**
     * Constructs an activity containing the passed Dhcp message, the source pcap activity will be replaced.
     *
     * @param source      The object on which the Activity occurred.
     * @param dhcpMessage the decoded Dhcp message
     * @throws IllegalArgumentException if source is null.
     */
    public DhcpActivity(PcapActivity source, DhcpMessage dhcpMessage) {
        super(source);
        pcapActivity = source;
        this.dhcpMessage = dhcpMessage;

        replaceActivity(source);
    }

    /**
     * @return the source on which the ArpActivity occurred or the final PcapActivity that led to the fully
     * decoded packet.
     */
    public PcapActivity getPcapActivity() {
        return pcapActivity;
    }

    /**
     * @return the decoded Dhcp content
     */
    public DhcpMessage getDhcpMessage() {
        return dhcpMessage;
    }

    @Override
    public String getSourceAddressAsString() {
        if (dhcpMessage != null) {
            return String.format("%s - %s", String.valueOf(dhcpMessage.getClientAddress()), String.valueOf(dhcpMessage.getClientMac()));
        } else {
            return null;
        }
    }

    @Override
    public String getDestinationAddressAsString() {
        if (dhcpMessage != null) {
            return String.valueOf(dhcpMessage.getNextServerAddress());
        } else {
            return null;
        }
    }

    @Override
    public String toString() {
        return "DhcpActivity{" +
                "pcapActivity=" + pcapActivity +
                ", dhcpMessage=" + dhcpMessage +
                '}';
    }
}
