/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.activity.http;


import org.apache.http.HttpHeaders;

/**
 * The following header definitions were taken from the {@link org.apache.http.HttpHeaders} (released
 * under the Apache 2.0 license) class and wrapped into an enumeration to
 * provide a simple canonicalization method which constitutes a workaround
 * for the missing normalization of Kraken HTTP header fields (see
 * {@link org.krakenapps.pcap.decoder.http.HttpHeaders}).
 * This enum is also used directly inside Drools rule definitions.
 */
public enum HttpHeader {

    /**
     * RFC 2616 (HTTP/1.1) Section 14.1
     */
    ACCEPT(HttpHeaders.ACCEPT),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.2
     */
    ACCEPT_CHARSET(HttpHeaders.ACCEPT_CHARSET),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.3
     */
    ACCEPT_ENCODING(HttpHeaders.ACCEPT_ENCODING),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.4
     */
    ACCEPT_LANGUAGE(HttpHeaders.ACCEPT_LANGUAGE),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.5
     */
    ACCEPT_RANGES(HttpHeaders.ACCEPT_RANGES),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.6
     */
    AGE(HttpHeaders.AGE),

    /**
     * RFC 1945 (HTTP/1.0) Section 10.1, RFC 2616 (HTTP/1.1) Section 14.7
     */
    ALLOW(HttpHeaders.ALLOW),

    /**
     * RFC 1945 (HTTP/1.0) Section 10.2, RFC 2616 (HTTP/1.1) Section 14.8
     */
    AUTHORIZATION(HttpHeaders.AUTHORIZATION),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.9
     */
    CACHE_CONTROL(HttpHeaders.CACHE_CONTROL),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.10
     */
    CONNECTION(HttpHeaders.CONNECTION),

    /**
     * RFC 1945 (HTTP/1.0) Section 10.3, RFC 2616 (HTTP/1.1) Section 14.11
     */
    CONTENT_ENCODING(HttpHeaders.CONTENT_ENCODING),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.12
     */
    CONTENT_LANGUAGE(HttpHeaders.CONTENT_LANGUAGE),

    /**
     * RFC 1945 (HTTP/1.0) Section 10.4, RFC 2616 (HTTP/1.1) Section 14.13
     */
    CONTENT_LENGTH(HttpHeaders.CONTENT_LENGTH),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.14
     */
    CONTENT_LOCATION(HttpHeaders.CONTENT_LOCATION),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.15
     */
    CONTENT_MD5(HttpHeaders.CONTENT_MD5),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.16
     */
    CONTENT_RANGE(HttpHeaders.CONTENT_RANGE),

    /**
     * RFC 1945 (HTTP/1.0) Section 10.5, RFC 2616 (HTTP/1.1) Section 14.17
     */
    CONTENT_TYPE(HttpHeaders.CONTENT_TYPE),

    /**
     * RFC 1945 (HTTP/1.0) Section 10.6, RFC 2616 (HTTP/1.1) Section 14.18
     */
    DATE(HttpHeaders.DATE),

    /**
     * RFC 2518 (WevDAV) Section 9.1
     */
    DAV(HttpHeaders.DAV),

    /**
     * RFC 2518 (WevDAV) Section 9.2
     */
    DEPTH(HttpHeaders.DEPTH),

    /**
     * RFC 2518 (WevDAV) Section 9.3
     */
    DESTINATION(HttpHeaders.DESTINATION),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.19
     */
    ETAG(HttpHeaders.ETAG),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.20
     */
    EXPECT(HttpHeaders.EXPECT),

    /**
     * RFC 1945 (HTTP/1.0) Section 10.7, RFC 2616 (HTTP/1.1) Section 14.21
     */
    EXPIRES(HttpHeaders.EXPIRES),

    /**
     * RFC 1945 (HTTP/1.0) Section 10.8, RFC 2616 (HTTP/1.1) Section 14.22
     */
    FROM(HttpHeaders.FROM),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.23
     */
    HOST(HttpHeaders.HOST),

    /**
     * RFC 2518 (WevDAV) Section 9.4
     */
    IF(HttpHeaders.IF),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.24
     */
    IF_MATCH(HttpHeaders.IF_MATCH),

    /**
     * RFC 1945 (HTTP/1.0) Section 10.9, RFC 2616 (HTTP/1.1) Section 14.25
     */
    IF_MODIFIED_SINCE(HttpHeaders.IF_MODIFIED_SINCE),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.26
     */
    IF_NONE_MATCH(HttpHeaders.IF_NONE_MATCH),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.27
     */
    IF_RANGE(HttpHeaders.IF_RANGE),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.28
     */
    IF_UNMODIFIED_SINCE(HttpHeaders.IF_UNMODIFIED_SINCE),

    /**
     * RFC 1945 (HTTP/1.0) Section 10.10, RFC 2616 (HTTP/1.1) Section 14.29
     */
    LAST_MODIFIED(HttpHeaders.LAST_MODIFIED),

    /**
     * RFC 1945 (HTTP/1.0) Section 10.11, RFC 2616 (HTTP/1.1) Section 14.30
     */
    LOCATION(HttpHeaders.LOCATION),

    /**
     * RFC 2518 (WevDAV) Section 9.5
     */
    LOCK_TOKEN(HttpHeaders.LOCK_TOKEN),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.31
     */
    MAX_FORWARDS(HttpHeaders.MAX_FORWARDS),

    /**
     * RFC 2518 (WevDAV) Section 9.6
     */
    OVERWRITE(HttpHeaders.OVERWRITE),

    /**
     * RFC 1945 (HTTP/1.0) Section 10.12, RFC 2616 (HTTP/1.1) Section 14.32
     */
    PRAGMA(HttpHeaders.PRAGMA),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.33
     */
    PROXY_AUTHENTICATE(HttpHeaders.PROXY_AUTHENTICATE),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.34
     */
    PROXY_AUTHORIZATION(HttpHeaders.PROXY_AUTHORIZATION),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.35
     */
    RANGE(HttpHeaders.RANGE),

    /**
     * RFC 1945 (HTTP/1.0) Section 10.13, RFC 2616 (HTTP/1.1) Section 14.36
     */
    REFERER(HttpHeaders.REFERER),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.37
     */
    RETRY_AFTER(HttpHeaders.RETRY_AFTER),

    /**
     * RFC 1945 (HTTP/1.0) Section 10.14, RFC 2616 (HTTP/1.1) Section 14.38
     */
    SERVER(HttpHeaders.SERVER),

    /**
     * RFC 2518 (WevDAV) Section 9.7
     */
    STATUS_URI(HttpHeaders.STATUS_URI),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.39
     */
    TE(HttpHeaders.TE),

    /**
     * RFC 2518 (WevDAV) Section 9.8
     */
    TIMEOUT(HttpHeaders.TIMEOUT),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.40
     */
    TRAILER(HttpHeaders.TRAILER),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.41
     */
    TRANSFER_ENCODING(HttpHeaders.TRANSFER_ENCODING),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.42
     */
    UPGRADE(HttpHeaders.UPGRADE),

    /**
     * RFC 1945 (HTTP/1.0) Section 10.15, RFC 2616 (HTTP/1.1) Section 14.43
     */
    USER_AGENT(HttpHeaders.USER_AGENT),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.44
     */
    VARY(HttpHeaders.VARY),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.45
     */
    VIA(HttpHeaders.VIA),

    /**
     * RFC 2616 (HTTP/1.1) Section 14.46
     */
    WARNING(HttpHeaders.WARNING), WWW_AUTHENTICATE(HttpHeaders.WWW_AUTHENTICATE);

    private final String name;

    HttpHeader(String httpHeader) {
        this.name = httpHeader;
    }

    /**
     * Canonicalizes a header as encountered by various decoders, i.e. it takes a String, representative for a header,
     * and tries to return an enumeration object instead.
     * This method should be considered both, inefficient and potentially unreliable, because it does not remove any
     * whitespace nor does handle encoding issues.
     * A simple equalsIgnoreCase is performed against the header enum and the passed String.
     *
     * @param wildHeader a non-null String that represent a HTTP header field key
     * @return a enum object representing the header
     * @throws java.lang.IllegalArgumentException if no header was found for wildHeader or wildHeader is a null pointer
     */
    public static HttpHeader canonicalizeHeader(String wildHeader) {
        if (wildHeader != null) {
            for (HttpHeader h : HttpHeader.values()) {
                if (wildHeader.equalsIgnoreCase(h.name)) {
                    return h;
                }
            }
        }
        throw new IllegalArgumentException();
    }

    @Override
    public String toString() {
        return name;
    }

    public String getName() {
        return name;
    }
}