/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.activity.http;


import at.jku.fim.rubanetra.protocol.activity.AbstractReplaceableActivity;

/**
 * Represents a deduction that was performed by rule-based reasoning that resulted in the fact that the encountered
 * a {@link at.jku.fim.rubanetra.protocol.activity.http.HttpActivity}-headers contained image-related
 * metadata.
 * This class should be considered a convenience class that tries to simplify the collection of derived information
 * by the Drools rule specifications.
 */
public class HttpImageActivity extends AbstractReplaceableActivity {
    private static final long serialVersionUID = -6487431475099739380L;
    private String imageType;
    private String imagePath;

    public HttpImageActivity(HttpActivity httpActivity) {
        super(httpActivity);
        imagePath = null;
        imageType = null;
        extendActivity(httpActivity);
    }

    /**
     * @return the type or format of the image as encountered or derived
     */
    public String getImageType() {
        return imageType;
    }

    /**
     * @param imageType the type or format of the image to set
     */
    public void setImageType(String imageType) {
        this.imageType = imageType;
    }

    /**
     * @return the absolute or relative path of the image as encountered or derived
     */
    public String getImagePath() {
        return imagePath;
    }

    /**
     * @param imagePath the path of the image to set
     */
    public void setImagePath(String imagePath) {
        this.imagePath = imagePath;
    }

    @Override
    public String toString() {
        return "HttpImageActivity{" +
                "imageType='" + imageType + '\'' +
                ", imagePath='" + imagePath + '\'' +
                '}';
    }
}
