/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.activity.icmp;


import at.jku.fim.rubanetra.protocol.activity.AbstractReplaceableActivity;
import org.kie.api.definition.type.Role;
import org.kie.api.definition.type.Role.Type;

/**
 * Represents the derived fact, that both an Echo request and a related Echo reply were encountered.
 * This activity will be constructed by rule evaluations.
 * ENHANCEMENT: ICMPv6
 */
@Role(Type.FACT)
public class PingActivity extends AbstractReplaceableActivity {
    private static final long serialVersionUID = -7127689333196188386L;
    private final Icmpv4Activity request;
    private final Icmpv4Activity reply;

    /**
     * Constructs a new Ping activity and replaces both the echo request/reply.
     * @param request the echo request
     * @param reply the corresponding and matched echo reply
     */
    public PingActivity(Icmpv4Activity request, Icmpv4Activity reply) {
        super(request);
        this.request = request;
        this.reply = reply;
        replaceActivity(request);
        replaceActivity(reply);
    }

    /**
     * @return the encountered echo request
     */
    public Icmpv4Activity getRequest() {
        return request;
    }

    /**
     * @return the matched echo reply
     */
    public Icmpv4Activity getReply() {
        return reply;
    }

    @Override
    public String getSourceAddressAsString() {
        return getRequest().getSourceAddressAsString();
    }

    @Override
    public String getDestinationAddressAsString() {
        return getReply().getDestinationAddressAsString();
    }

    @Override
    public String toString() {
        return "PingActivity{" +
                "request=" + request +
                ", reply=" + reply +
                '}';
    }
}
