/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.activity.msn;


import at.jku.fim.rubanetra.pcap.PcapActivity;
import at.jku.fim.rubanetra.protocol.activity.AbstractReplaceableActivity;
import org.kie.api.definition.type.Role;
import org.kie.api.definition.type.Role.Type;

/**
 * Encapsulates MSN chat messages.
 */
@Role(Type.EVENT)
public class MsnActivity extends AbstractReplaceableActivity {
    private static final long serialVersionUID = -4422657387707609350L;
    private final PcapActivity pcapActivity;
    private final String account;
    private final String chat;

    /**
     * Constructs a new MSN chat activity, replaces the source pcap activity on which this event occurred.
     * @param source the source event on which this activity occurred
     * @param account the account name that was used for the chat
     * @param chat the chat message
     */
    public MsnActivity(PcapActivity source, String account, String chat) {
        super(source);
        pcapActivity = source;
        this.account = account;
        this.chat = chat;
        replaceActivity(source);
    }

    /**
     * @return the source on which this activity occurred or the final PcapActivity that led to the fully
     * decoded packet.
     */
    public PcapActivity getPcapActivity() {
        return pcapActivity;
    }

    /**
     * @return the account name used for chatting
     */
    public String getAccount() {
        return account;
    }

    /**
     * @return the chat message
     */
    public String getChat() {
        return chat;
    }

    @Override
    public String getSourceAddressAsString() {
        return getAccount();
    }

    @Override
    public String toString() {
        return "MsnActivity{" +
                "pcapActivity=" + pcapActivity +
                ", account='" + account + '\'' +
                ", chat='" + chat + '\'' +
                '}';
    }
}