/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.activity.netbios;

import at.jku.fim.rubanetra.pcap.PcapActivity;
import at.jku.fim.rubanetra.protocol.activity.AbstractReplaceableActivity;
import org.krakenapps.pcap.decoder.netbios.NetBiosDatagramPacket;
import org.krakenapps.pcap.decoder.netbios.NetBiosNamePacket;

/**
 * Encapsulates {@link org.krakenapps.pcap.decoder.netbios.NetBiosDatagramPacket}s.
 */
public class NetbiosActivity extends AbstractReplaceableActivity {
    private final PcapActivity pcapActivity;
    private final NetBiosNamePacket namePacket;
    private final NetBiosDatagramPacket datagramPacket;

    /**
     * Constructs a prototypical Event.
     *
     * @param source The object on which the Event initially occurred (will be replaced).
     * @throws IllegalArgumentException if source is null.
     */
    public NetbiosActivity(PcapActivity source, NetBiosDatagramPacket datagramPacket) {
        super(source);
        pcapActivity = source;
        this.datagramPacket = datagramPacket;
        this.namePacket = null;

        replaceActivity(source);
    }

    /**
     * Constructs a prototypical Event.
     *
     * @param source The object on which the Event initially occurred (will be replaced).
     * @throws IllegalArgumentException if source is null.
     */
    public NetbiosActivity(PcapActivity source, NetBiosNamePacket namePacket) {
        super(source);
        pcapActivity = source;
        this.namePacket = namePacket;
        this.datagramPacket = null;

        replaceActivity(source);
    }

    /**
     * @return the source on which this activity occurred or the final PcapActivity that led to the fully
     * decoded packet.
     */
    public PcapActivity getPcapActivity() {
        return pcapActivity;
    }

    /**
     * @return the decoded packet (by Kraken)
     */
    public NetBiosNamePacket getNamePacket() {
        return namePacket;
    }

    /**
     * @return the original decoded datagram.
     */
    public NetBiosDatagramPacket getDatagramPacket() {
        return datagramPacket;
    }

    @Override
    public String toString() {
        return "NetbiosActivity{" +
                "pcapActivity=" + pcapActivity +
                ", namePacket=" + namePacket +
                ", datagramPacket=" + datagramPacket +
                '}';
    }
}
