/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.activity.pop3;

import at.jku.fim.rubanetra.pcap.PcapActivity;
import at.jku.fim.rubanetra.protocol.activity.AbstractReplaceableActivity;
import org.krakenapps.mime.MimeHeader;
import org.krakenapps.pcap.decoder.pop3.Pop3Data;


/**
 * TODO: this class represents a partial Pop3-Activity, i.e. it should be reassembled by drools into a single session
 * TODO: based on the source/destination socket addresses
 */
public class Pop3Activity extends AbstractReplaceableActivity {
    private static final long serialVersionUID = 5803080617646591389L;
    private final PcapActivity pcapActivity;
    private final Type subType;
    /**
     * RECEIVE partial Type fields: header, data
     */
    private MimeHeader header;
    private Pop3Data data;

    /**
     * COMMAND partial Type field: command
     */
    private String command;

    /**
     * RESPONSE partial Type field: response
     */
    private String response;

    /**
     * Constructs a prototypical Event.
     *
     * @param source The object on which the Event initially occurred.
     * @throws IllegalArgumentException if source is null.
     */
    public Pop3Activity(PcapActivity source, Type partialActivityType) {
        super(source);
        pcapActivity = source;
        this.subType = partialActivityType;
    }

    /**
     * @return the source on which this activity occurred or the final PcapActivity that led to the fully
     * decoded packet.
     */
    public PcapActivity getPcapActivity() {
        return pcapActivity;
    }

    /**
     * @return the subtype of this POP activity
     */
    public Type getSubType() {
        return subType;
    }

    /**
     * @return the decoded {@link org.krakenapps.mime.MimeHeader} if available, null otherwise
     */
    public MimeHeader getHeader() {
        return header;
    }

    /**
     * This method will be called by {@link at.jku.fim.rubanetra.protocol.handler.KrakenPop3Handler}
     * in order to build a partial POP session.
     *
     * @param header the decoded MIME header.
     */
    public void setHeader(MimeHeader header) {
        this.header = header;
    }

    /**
     * @return the decoded {@link org.krakenapps.pcap.decoder.pop3.Pop3Data} if available, null otherwise
     */
    public Pop3Data getData() {
        return data;
    }

    /**
     * This method will be called by {@link at.jku.fim.rubanetra.protocol.handler.KrakenPop3Handler}
     * during the decoding process.
     *
     * @param data the decoded POP data
     */
    public void setData(Pop3Data data) {
        this.data = data;
    }

    /**
     * @return the decoded command string if available, null otherwise
     */
    public String getCommand() {
        return command;
    }

    /**
     * This method will be called by {@link at.jku.fim.rubanetra.protocol.handler.KrakenPop3Handler} in
     * order to build a partial session during the encoding process.
     *
     * @param command the decoded command.
     */
    public void setCommand(String command) {
        this.command = command;
    }

    /**
     * @return the decoded response message
     */
    public String getResponse() {
        return response;
    }

    /**
     * This method will be called by {@link at.jku.fim.rubanetra.protocol.handler.KrakenPop3Handler} in
     * order to build a partial session during the encoding process.
     *
     * @param response the decoded response string
     */
    public void setResponse(String response) {
        this.response = response;
    }

    /**
     * POP3 Activity type of the surrounding object
     */
    public enum Type {
        RECEIVE, COMMAND, RESPONSE
    }

    @Override
    public String toString() {
        return "Pop3Activity{" +
                "pcapActivity=" + pcapActivity +
                ", subType=" + subType +
                ", header=" + header +
                ", data=" + data +
                ", command='" + command + '\'' +
                ", response='" + response + '\'' +
                '}';
    }
}
