/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.activity.smtp;


import at.jku.fim.rubanetra.pcap.PcapActivity;
import at.jku.fim.rubanetra.protocol.activity.AbstractReplaceableActivity;
import org.kie.api.definition.type.Role;
import org.kie.api.definition.type.Role.Type;

/**
 * Represents an abstraction for {@link at.jku.fim.rubanetra.protocol.activity.smtp.SmtpCommandActivity},
 * {@link at.jku.fim.rubanetra.protocol.activity.smtp.SmtpReplyActivity} and
 * {@link at.jku.fim.rubanetra.protocol.activity.smtp.SmtpSendActivity} that may be used by Drools rules
 * in order to determine that some SMTP related traffic occurred for a given {@link at.jku.fim.rubanetra.pcap.PcapActivity}.
 */
@Role(Type.EVENT)
public abstract class SmtpActivity extends AbstractReplaceableActivity {
    private static final long serialVersionUID = 6159462782844297508L;
    private final PcapActivity pcapActivity;

    /**
     * Constructs a SMTP activity and replaced the source pcap activity on which this event occurred.
     *
     * @param source the pcap activity on which this event occurred
     */
    public SmtpActivity(PcapActivity source) {
        super(source);
        pcapActivity = source;
        replaceActivity(source);
    }

    /**
     * @return the source on which this activity occurred or the final PcapActivity that led to the fully
     * decoded packet.
     */
    public PcapActivity getPcapActivity() {
        return pcapActivity;
    }

    @Override
    public String toString() {
        return "SmtpActivity{" +
                "pcapActivity=" + pcapActivity +
                '}';
    }
}