/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.activity.smtp;


import at.jku.fim.rubanetra.pcap.PcapActivity;

/**
 * Encapsulates the SMTP command and parameter values.
 */
public class SmtpCommandActivity extends SmtpActivity {
    private static final long serialVersionUID = 1579865560446923831L;
    private final String command;
    private final String parameter;

    /**
     * Constructs a new command activity and replaces the source pcap activity.
     *
     * @param source    the pcap activity on which this event occurred
     * @param command   the command string
     * @param parameter the parameter value
     */
    public SmtpCommandActivity(PcapActivity source, String command, String parameter) {
        super(source);
        this.command = command;
        this.parameter = parameter;
    }

    /**
     * @return the command value
     */
    public String getCommand() {
        return command;
    }

    /**
     * @return the parameter value
     */
    public String getParameter() {
        return parameter;
    }

    @Override
    public String toString() {
        return "SmtpCommandActivity{" +
                "command='" + command + '\'' +
                ", parameter='" + parameter + '\'' +
                '}';
    }
}
