/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.activity.smtp;


import at.jku.fim.rubanetra.pcap.PcapActivity;

/**
 * Encapsulates the SMTP reply code number and the SMTP message.
 */
public class SmtpReplyActivity extends SmtpActivity {
    private static final long serialVersionUID = 7746759264444813246L;
    private final int code;
    private final String message;

    /**
     * Constructs a new SMTP reply activity and replaces the source pcap activity on which this event occurred initially.
     *
     * @param source  the pcap activity on which this event occurred.
     * @param code    the code number of the reply
     * @param message the decoded message itself
     */
    public SmtpReplyActivity(PcapActivity source, int code, String message) {
        super(source);
        this.code = code;
        this.message = message;
    }

    /**
     * @return the reply code number
     */
    public int getCode() {
        return code;
    }

    /**
     * @return the decoded message
     */
    public String getMessage() {
        return message;
    }

    @Override
    public String toString() {
        return "SmtpReplyActivity{" +
                "code=" + code +
                ", message='" + message + '\'' +
                '}';
    }
}
