/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.activity.smtp;


import at.jku.fim.rubanetra.pcap.PcapActivity;
import org.krakenapps.mime.MimeHeader;
import org.krakenapps.pcap.decoder.smtp.SmtpData;

/**
 * Encapsulates the {@link org.krakenapps.mime.MimeHeader} and the {@link org.krakenapps.pcap.decoder.smtp.SmtpData} for
 * SMTP.
 */
public class SmtpSendActivity extends SmtpActivity {
    private static final long serialVersionUID = -5050757703933049654L;
    private final MimeHeader header;
    private final SmtpData data;

    /**
     * Constructs a new Smtp send activity that replaces the source pcap activity on which this event occurred.
     *
     * @param source the pcap activity on which the SMTP send activity occurred.
     * @param header the decoded MIME header
     * @param data   the SMTP data
     */
    public SmtpSendActivity(PcapActivity source, MimeHeader header, SmtpData data) {
        super(source);
        this.header = header;
        this.data = data;
    }

    /**
     * @return the decoded MIME header (Kraken)
     */
    public MimeHeader getHeader() {
        return header;
    }

    /**
     * @return the decoded SMTP data (Kraken)
     */
    public SmtpData getData() {
        return data;
    }

    @Override
    public String toString() {
        return "SmtpSendActivity{" +
                "header=" + header +
                ", data=" + data +
                '}';
    }
}
