/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.activity.snmp;

import at.jku.fim.rubanetra.pcap.PcapActivity;
import at.jku.fim.rubanetra.protocol.activity.AbstractReplaceableActivity;
import org.krakenapps.pcap.decoder.snmp.v1.Pdu;

import java.net.InetSocketAddress;

/**
 * Encapsulates a {@link org.krakenapps.pcap.decoder.snmp.v1.Pdu} object including source and destination
 * L3/L4 addresses.
 */
public class Snmpv1Activity extends AbstractReplaceableActivity {
    private static final long serialVersionUID = 398825166451021814L;
    private final PcapActivity pcapActivity;
    private final Pdu pdu;
    private final InetSocketAddress sourceSocketAddress, destinationSocketAddress;

    /**
     * Constructs a prototypical Event.
     *
     * @param source             The object on which the Event initially occurred.
     * @param pdu                the decoded {@link org.krakenapps.pcap.decoder.snmp.v1.Pdu}
     * @param sourceAddress      the L3/L4 source address
     * @param destinationAddress the L3/L4 destination address
     */
    public Snmpv1Activity(PcapActivity source, Pdu pdu, InetSocketAddress sourceAddress, InetSocketAddress destinationAddress) {
        super(source);
        pcapActivity = source;
        this.pdu = pdu;
        this.sourceSocketAddress = sourceAddress;
        this.destinationSocketAddress = destinationAddress;

        replaceActivity(source);
    }

    /**
     * @return the source on which this activity occurred or the final PcapActivity that led to the fully
     * decoded packet.
     */
    public PcapActivity getPcapActivity() {
        return pcapActivity;
    }

    /**
     * @return the decoded PDU
     */
    public Pdu getPdu() {
        return pdu;
    }

    /**
     * @return the L3/L4 source address
     */
    public InetSocketAddress getSourceSocketAddress() {
        return sourceSocketAddress;
    }

    /**
     * @return the L3/L4 destination address
     */
    public InetSocketAddress getDestinationSocketAddress() {
        return destinationSocketAddress;
    }

    @Override
    public String getSourceAddressAsString() {
        return String.valueOf(getSourceSocketAddress());
    }

    @Override
    public String getDestinationAddressAsString() {
        return String.valueOf(getDestinationSocketAddress());
    }

    @Override
    public String toString() {
        return "Snmpv1Activity{" +
                "pcapActivity=" + pcapActivity +
                ", pdu=" + pdu +
                ", sourceSocketAddress=" + sourceSocketAddress +
                ", destinationSocketAddress=" + destinationSocketAddress +
                '}';
    }
}
