/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.activity.telnet;

import at.jku.fim.rubanetra.pcap.PcapActivity;
import at.jku.fim.rubanetra.protocol.activity.AbstractReplaceableActivity;
import org.krakenapps.pcap.decoder.telnet.AnsiMode;
import org.krakenapps.pcap.decoder.telnet.TelnetCommand;
import org.krakenapps.pcap.decoder.telnet.TelnetOption;

import java.util.Arrays;

/**
 * TODO: partial types -> drools reassembly
 */
public class TelnetActivity extends AbstractReplaceableActivity {
    private static final long serialVersionUID = -1020544168748948881L;
    private final PcapActivity pcapActivity;
    private final Type subType;

    /**
     * (CLIENT|SERVER)_(COMMAND|ANSICONTROL)
     */
    private TelnetCommand command;
    /**
     * (CLIENT|SERVER)_(COMMAND)
     */
    private TelnetOption option;
    private byte[] data;

    /**
     * (CLIENT|SERVER)_ANSICONTROL
     */
    private AnsiMode ansiMode;
    private int[] arguments;

    /**
     * (CLIENT|SERVER)_DATA
     */
    private String text;

    /**
     * (CLIENT|SERVER)_TITLE
     */
    private String title;

    /**
     * Constructs a prototypical Event.
     *
     * @param source              The object on which the Event initially occurred (will be replaced).
     * @param partialActivityType the subtype of this activity (to be reassembled)
     * @throws IllegalArgumentException if source is null.
     */
    public TelnetActivity(PcapActivity source, Type partialActivityType) {
        super(source);
        pcapActivity = source;
        this.subType = partialActivityType;

        replaceActivity(source);
    }

    /**
     * @return the source on which this activity occurred or the final PcapActivity that led to the fully
     * decoded packet.
     */
    public PcapActivity getPcapActivity() {
        return pcapActivity;
    }

    /**
     * @return the subtype of this activity for reassembly
     */
    public Type getSubType() {
        return subType;
    }

    /**
     * @return the decoded {@link org.krakenapps.pcap.decoder.telnet.TelnetCommand}
     */
    public TelnetCommand getCommand() {
        return command;
    }

    /**
     * Set by {@link at.jku.fim.rubanetra.protocol.handler.KrakenTelnetHandler}
     * @param command the decoded {@link org.krakenapps.pcap.decoder.telnet.TelnetCommand}
     */
    public void setCommand(TelnetCommand command) {
        this.command = command;
    }

    /**
     * @return the decoded {@link org.krakenapps.pcap.decoder.telnet.TelnetOption}
     */
    public TelnetOption getOption() {
        return option;
    }

    /**
     * Set by {@link at.jku.fim.rubanetra.protocol.handler.KrakenTelnetHandler}
     * @param option the decoded {@link org.krakenapps.pcap.decoder.telnet.TelnetOption}
     */
    public void setOption(TelnetOption option) {
        this.option = option;
    }

    /**
     * @return the available telnet data (provided by the decoder)
     */
    public byte[] getData() {
        return data;
    }

    /**
     * Set by {@link at.jku.fim.rubanetra.protocol.handler.KrakenTelnetHandler}
     * @param data the telnet data
     */
    public void setData(byte[] data) {
        this.data = data;
    }

    /**
     * @return the decoded {@link org.krakenapps.pcap.decoder.telnet.AnsiMode}
     */
    public AnsiMode getAnsiMode() {
        return ansiMode;
    }

    /**
     * Set by {@link at.jku.fim.rubanetra.protocol.handler.KrakenTelnetHandler}
     * @param ansiMode the decoded {@link org.krakenapps.pcap.decoder.telnet.AnsiMode}
     */
    public void setAnsiMode(AnsiMode ansiMode) {
        this.ansiMode = ansiMode;
    }

    /**
     * @return the available telnet arguments
     * @see org.krakenapps.pcap.decoder.telnet.TelnetDecoder
     */
    public int[] getArguments() {
        return arguments;
    }

    /**
     * Set by {@link at.jku.fim.rubanetra.protocol.handler.KrakenTelnetHandler}
     * @param arguments the available telnet arguments
     */
    public void setArguments(int[] arguments) {
        this.arguments = arguments;
    }

    /**
     * @return the decoded telnet text
     */
    public String getText() {
        return text;
    }

    /**
     * Set by {@link at.jku.fim.rubanetra.protocol.handler.KrakenTelnetHandler}
     * @param text the decoded telnet text
     */
    public void setText(String text) {
        this.text = text;
    }

    /**
     * @return the decoded title
     */
    public String getTitle() {
        return title;
    }

    /**
     * Set by {@link at.jku.fim.rubanetra.protocol.handler.KrakenTelnetHandler}
     * @param title the decoded title
     */
    public void setTitle(String title) {
        this.title = title;
    }

    public enum Type {
        CLIENT_COMMAND, SERVER_COMMAND, CLIENT_ANSICONTROL, SERVER_ANSICONTROL,
        CLIENT_DATA, SERVER_DATA, CLIENT_TITLE, SERVER_TITLE
    }

    @Override
    public String toString() {
        return "TelnetActivity{" +
                "pcapActivity=" + pcapActivity +
                ", subType=" + subType +
                ", command=" + command +
                ", option=" + option +
                ", data=" + Arrays.toString(data) +
                ", ansiMode=" + ansiMode +
                ", arguments=" + Arrays.toString(arguments) +
                ", text='" + text + '\'' +
                ", title='" + title + '\'' +
                '}';
    }
}
