/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.handler;

import at.jku.fim.rubanetra.config.model.KrakenApplicationProtocolId;
import at.jku.fim.rubanetra.config.model.ProtocolId;
import at.jku.fim.rubanetra.protocol.KrakenBaseProtocol;
import at.jku.fim.rubanetra.protocol.activity.dhcp.DhcpActivity;
import org.krakenapps.pcap.Protocol;
import org.krakenapps.pcap.decoder.dhcp.DhcpDecoder;
import org.krakenapps.pcap.decoder.dhcp.DhcpMessage;

/**
 * Utilizes a {@link org.krakenapps.pcap.decoder.dhcp.DhcpDecoder} in order to receive decoded DHCP data, which
 * is in turn distributed as {@link at.jku.fim.rubanetra.protocol.activity.dhcp.DhcpActivity} to
 * interested observers.
 * This class does not define any concrete bindings.
 */
public class KrakenDhcpHandler extends KrakenBaseProtocol {
    public static final String PROPERTY_NEW_DHCP_ACTIVITY = "newDhcpActivity";
    private final DhcpDecoder krakenDhcpDecoder;

    public KrakenDhcpHandler() {
        krakenDhcpDecoder = new DhcpDecoder();
        krakenDhcpDecoder.register(this::fireNewDhcpActivity);
    }

    private void fireNewDhcpActivity(DhcpMessage dhcpMessage) {
        DhcpActivity dhcpActivity = new DhcpActivity(getCurrentPcapActivity(), dhcpMessage);
        propertyChangeSupport.firePropertyChange(PROPERTY_NEW_DHCP_ACTIVITY, null, dhcpActivity);
    }

    public static final KrakenApplicationProtocolId krakenDhcpProtocolId = new KrakenApplicationProtocolId() {
        private final String protocolId = Protocol.DHCP.name();

        @Override
        public Protocol getKrakenApplicationProtocol() {
            return Protocol.DHCP;
        }

        @Override
        public String getProtocolId() {
            return protocolId;
        }

        @Override
        public String getName() {
            return "Dhcp";
        }

        @Override
        public String toString() {
            return getName();
        }
    };

    @Override
    public ProtocolId getProtocolId() {
        return krakenDhcpProtocolId;
    }

    public DhcpDecoder getKrakenDhcpDecoder() {
        return krakenDhcpDecoder;
    }

}
