/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.handler;

import at.jku.fim.rubanetra.config.model.KrakenApplicationProtocolId;
import at.jku.fim.rubanetra.config.model.ProtocolId;
import at.jku.fim.rubanetra.protocol.KrakenBaseProtocol;
import at.jku.fim.rubanetra.protocol.activity.ftp.FtpActivity;
import org.krakenapps.pcap.Protocol;
import org.krakenapps.pcap.decoder.ftp.FtpDecoder;
import org.krakenapps.pcap.decoder.ftp.FtpProcessor;
import org.krakenapps.pcap.decoder.tcp.TcpPortProtocolMapper;

import java.io.InputStream;

/**
 * This is an Kraken application layer decoder handler, i.e. it does not provide any forward bindings.
 * Internally, a {@link org.krakenapps.pcap.decoder.ftp.FtpDecoder} is used to build partial
 * {@link at.jku.fim.rubanetra.protocol.activity.ftp.FtpActivity} instances.
 */
public class KrakenFtpHandler extends KrakenBaseProtocol {
    public static final String PROPERTY_NEW_PARTIAL_FTP_ACTIVITY = "newPartialFtpActivity";
    public static final KrakenApplicationProtocolId krakenFtpProtocolId = new KrakenApplicationProtocolId() {
        private final String protocolId = Protocol.FTP.name();

        @Override
        public Protocol getKrakenApplicationProtocol() {
            return Protocol.FTP;
        }

        @Override
        public String getProtocolId() {
            return protocolId;
        }

        @Override
        public String getName() {
            return "Ftp";
        }

        @Override
        public String toString() {
            return getName();
        }
    };

    private final FtpDecoder krakenFtpDecoder;
    private final FtpProcessor ftpProcessor = new FtpProcessor() {
        @Override
        public void onCommand(String command) {
            FtpActivity activity = new FtpActivity(getCurrentPcapActivity(), FtpActivity.Type.COMMAND, command);
            fireNewPartialFtpActivity(activity);
        }

        @Override
        public void onReply(String reply) {
            FtpActivity activity = new FtpActivity(getCurrentPcapActivity(), FtpActivity.Type.REPLY, reply);
            fireNewPartialFtpActivity(activity);
        }

        @Override
        public void viewList(byte[] list) {
            FtpActivity activity = new FtpActivity(getCurrentPcapActivity(), FtpActivity.Type.VIEW_LIST, list);
            fireNewPartialFtpActivity(activity);
        }

        @Override
        public void onExtractFile(InputStream is, String fileName) {

        }
    };

    public KrakenFtpHandler() {
        krakenFtpDecoder = new FtpDecoder(new TcpPortProtocolMapper());
        krakenFtpDecoder.register(ftpProcessor);
    }

    private void fireNewPartialFtpActivity(FtpActivity partialFtpActivity) {
        propertyChangeSupport.firePropertyChange(PROPERTY_NEW_PARTIAL_FTP_ACTIVITY, null, partialFtpActivity);
    }

    @Override
    public ProtocolId getProtocolId() {
        return krakenFtpProtocolId;
    }

    /**
     * @return the FTP decoder that is used internally
     */
    public FtpDecoder getKrakenFtpDecoder() {
        return krakenFtpDecoder;
    }
}
