/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.handler;


import at.jku.fim.rubanetra.config.model.KrakenApplicationProtocolId;
import at.jku.fim.rubanetra.config.model.ProtocolId;
import at.jku.fim.rubanetra.protocol.KrakenBaseProtocol;
import at.jku.fim.rubanetra.protocol.activity.http.HttpRequestActivity;
import at.jku.fim.rubanetra.protocol.activity.http.HttpResponseActivity;
import org.krakenapps.pcap.Protocol;
import org.krakenapps.pcap.decoder.http.HttpDecoder;
import org.krakenapps.pcap.decoder.http.HttpProcessor;
import org.krakenapps.pcap.decoder.http.HttpRequest;
import org.krakenapps.pcap.decoder.http.HttpResponse;
import org.krakenapps.pcap.util.Buffer;

/**
 * Represents an application layer Kraken decoder handler, i.e. it does not provide any forward bindings.
 * A {@link org.krakenapps.pcap.decoder.http.HttpDecoder} is used internally to decode HTTP data which is used to
 * build {@link at.jku.fim.rubanetra.protocol.activity.http.HttpRequestActivity} and
 * {@link at.jku.fim.rubanetra.protocol.activity.http.HttpResponseActivity} objects.
 * However, it does not handle Multipart data (the buffers will be silently discarded).
 */
public class KrakenHttpHandler extends KrakenBaseProtocol {
    public static final String NEW_HTTP_REQUEST_ACTIVITY_PROPERTY_NAME = "newHttpRequestActivity";
    public static final String NEW_HTTP_RESPONSE_ACTIVITY_PROPERTY_NAME = "newHttpResponseActivity";
    public static final KrakenApplicationProtocolId krakenHttpProtocolId = new KrakenApplicationProtocolId() {
        private final String protocolIdString = Protocol.HTTP.name();

        @Override
        public Protocol getKrakenApplicationProtocol() {
            return Protocol.HTTP;
        }

        @Override
        public String getProtocolId() {
            return protocolIdString;
        }

        @Override
        public String getName() {
            return "Http";
        }

        @Override
        public String toString() {
            return getName();
        }
    };
    private final HttpDecoder krakenHttpDecoder;

    public KrakenHttpHandler() {
        krakenHttpDecoder = new HttpDecoder();
        krakenHttpDecoder.register(new HttpProcessor() {

            @Override
            public void onResponse(HttpRequest req, HttpResponse resp) {
                fireNewHttpResponseActivity(resp);
            }

            @Override
            public void onRequest(HttpRequest req) {
                fireNewHttpRequestActivity(req);
            }

            @Override
            public void onMultipartData(Buffer buffer) {
            }
        });
    }

    protected void fireNewHttpRequestActivity(HttpRequest req) {
        HttpRequestActivity requestActivity = new HttpRequestActivity(getCurrentPcapActivity(), req);
        propertyChangeSupport.firePropertyChange(NEW_HTTP_REQUEST_ACTIVITY_PROPERTY_NAME, null, requestActivity);
    }

    protected void fireNewHttpResponseActivity(HttpResponse resp) {
        HttpResponseActivity responseActivity = new HttpResponseActivity(getCurrentPcapActivity(), resp);
        propertyChangeSupport.firePropertyChange(NEW_HTTP_RESPONSE_ACTIVITY_PROPERTY_NAME, null, responseActivity);
    }

    @Override
    public ProtocolId getProtocolId() {
        return krakenHttpProtocolId;
    }

    /**
     * @return the HTTP decoder that is used internally
     */
    public HttpDecoder getKrakenHttpDecoder() {
        return krakenHttpDecoder;
    }
}
