/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.handler;


import at.jku.fim.rubanetra.config.model.KrakenProtocolConfiguration;
import at.jku.fim.rubanetra.config.model.ProtocolId;
import at.jku.fim.rubanetra.protocol.KrakenBaseProtocol;
import at.jku.fim.rubanetra.protocol.activity.icmp.Icmpv6Activity;
import org.krakenapps.pcap.decoder.icmpv6.Icmpv6Decoder;
import org.krakenapps.pcap.decoder.icmpv6.Icmpv6Packet;

/**
 * Handles decoded ICMPv6 data received from a {@link org.krakenapps.pcap.decoder.icmpv6.Icmpv6Decoder} in order to
 * build {@link at.jku.fim.rubanetra.protocol.activity.icmp.Icmpv6Activity} objects.
 * This class does not provide any forward bindings.
 */
public class KrakenIcmpv6Handler extends KrakenBaseProtocol {
    public static final String NEW_ICMPV_6_ACTIVITY_PROPERTY_NAME = "newIcmpv6Activity";
    public static final ProtocolId krakenIcmpv6ProtocolId = new ProtocolId() {
        private final String protocolId = "Icmpv6";

        @Override
        public String getProtocolId() {
            return protocolId;
        }

        @Override
        public String getName() {
            return protocolId;
        }

        @Override
        public String toString() {
            return getName();
        }
    };

    private final Icmpv6Decoder krakenImpv6Decoder;

    public KrakenIcmpv6Handler() {
        krakenImpv6Decoder = new Icmpv6Decoder();
        krakenImpv6Decoder.register(this::fireNewIcmpActivity);
    }

    @Override
    public ProtocolId getProtocolId() {
        return krakenIcmpv6ProtocolId;
    }

    @Override
    public void initialize(KrakenProtocolConfiguration setting) {
        super.initialize(setting);
    }

    protected void fireNewIcmpActivity(Icmpv6Packet p) {
        Icmpv6Activity icmpActivity = new Icmpv6Activity(getCurrentPcapActivity(), p);
        propertyChangeSupport.firePropertyChange(NEW_ICMPV_6_ACTIVITY_PROPERTY_NAME, null, icmpActivity);
    }

    /**
     * @return the ICMPv6 decoder that is used internally
     */
    public Icmpv6Decoder getKrakenImpv6Decoder() {
        return krakenImpv6Decoder;
    }
}
