/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.handler;


import at.jku.fim.rubanetra.config.model.KrakenApplicationProtocolId;
import at.jku.fim.rubanetra.config.model.ProtocolId;
import at.jku.fim.rubanetra.protocol.KrakenBaseProtocol;
import at.jku.fim.rubanetra.protocol.activity.msn.MsnActivity;
import at.jku.fim.rubanetra.protocol.mapper.KrakenTcpProtocolMapperStrategy;
import at.jku.fim.rubanetra.protocol.mapper.KrakenTransportLayerMappingFactory;
import org.krakenapps.pcap.Protocol;
import org.krakenapps.pcap.decoder.msn.MsnDecoder;

/**
 * Handles Kraken's {@link org.krakenapps.pcap.decoder.msn.MsnDecoder} output
 * and creates suitable {@link at.jku.fim.rubanetra.protocol.activity.msn.MsnActivity} objects
 * during the process.
 * This class does not provide any bindings.
 */
public class KrakenMsnHandler extends KrakenBaseProtocol {
    public static final String NEW_MSN_ACTIVITY_PROPERTY_NAME = "newMsnActivity";
    public static final KrakenApplicationProtocolId krakenMsnProtocolId = new KrakenApplicationProtocolId() {
        private final String protocolId = Protocol.MSN.name();

        @Override
        public Protocol getKrakenApplicationProtocol() {
            return Protocol.MSN;
        }

        @Override
        public String getProtocolId() {
            return protocolId;
        }

        @Override
        public String getName() {
            return "Msn";
        }

        @Override
        public String toString() {
            return getName();
        }
    };
    private final KrakenTransportLayerMappingFactory mappingFactory = new KrakenTransportLayerMappingFactory();
    private KrakenTcpProtocolMapperStrategy tcpMappingStrategy;
    private MsnDecoder krakenMsnDecoder;

    public KrakenMsnHandler() {
        krakenMsnDecoder = new MsnDecoder();
        krakenMsnDecoder.register(this::fireNewMsnActivity);
    }

    private void fireNewMsnActivity(String account, String chat) {
        MsnActivity msnAct = new MsnActivity(getCurrentPcapActivity(), account, chat);
        propertyChangeSupport.firePropertyChange(NEW_MSN_ACTIVITY_PROPERTY_NAME, null, msnAct);
    }


    @Override
    public ProtocolId getProtocolId() {
        return krakenMsnProtocolId;
    }

    /**
     * @return the internally used MSN decoder
     */
    public MsnDecoder getKrakenMsnDecoder() {
        return krakenMsnDecoder;
    }
}
