/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.handler;

import at.jku.fim.rubanetra.config.model.KrakenApplicationProtocolId;
import at.jku.fim.rubanetra.config.model.ProtocolId;
import at.jku.fim.rubanetra.protocol.KrakenBaseProtocol;
import at.jku.fim.rubanetra.protocol.activity.netbios.NetbiosActivity;
import org.krakenapps.pcap.Protocol;
import org.krakenapps.pcap.decoder.netbios.NetBiosDecoder;

/**
 * This class tries to handle various Netbios events dispatched by the internally
 * used {@link org.krakenapps.pcap.decoder.netbios.NetBiosDecoder}.
 * Appropriate {@link at.jku.fim.rubanetra.protocol.activity.netbios.NetbiosActivity}
 * objects are constructed for those events, however, be aware that this class
 * has not yet been tested at all.
 * This class does not provide any bindings.
 */
public class KrakenNetbiosHandler extends KrakenBaseProtocol {
    public static final KrakenApplicationProtocolId krakenNetbiosProtocolId = new KrakenApplicationProtocolId() {
        @Override
        public Protocol getKrakenApplicationProtocol() {
            return Protocol.NETBIOS;
        }

        @Override
        public String getProtocolId() {
            return Protocol.NETBIOS.name();
        }

        @Override
        public String getName() {
            return "Netbios";
        }
    };

    private final NetBiosDecoder krakenNetbiosDecoder;

    public KrakenNetbiosHandler() {
        krakenNetbiosDecoder = new NetBiosDecoder();
        krakenNetbiosDecoder.registerDatagramProcessor(netBiosDatagramPacket -> {
            NetbiosActivity act = new NetbiosActivity(getCurrentPcapActivity(), netBiosDatagramPacket);
            fireNewNetbiosActivity(act);
        });
        krakenNetbiosDecoder.registerNameProcessor(netBiosNamePacket -> {
            NetbiosActivity act = new NetbiosActivity(getCurrentPcapActivity(), netBiosNamePacket);
            fireNewNetbiosActivity(act);
        });
    }

    private void fireNewNetbiosActivity(NetbiosActivity act) {
        propertyChangeSupport.firePropertyChange("newNetbiosActivity", null, act);
    }

    @Override
    public ProtocolId getProtocolId() {
        return krakenNetbiosProtocolId;
    }

    /**
     * @return the internally used NetBios decoder
     */
    public NetBiosDecoder getKrakenNetbiosDecoder() {
        return krakenNetbiosDecoder;
    }
}
