/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.handler;

import at.jku.fim.rubanetra.config.model.KrakenApplicationProtocolId;
import at.jku.fim.rubanetra.config.model.ProtocolId;
import at.jku.fim.rubanetra.protocol.KrakenBaseProtocol;
import at.jku.fim.rubanetra.protocol.activity.pop3.Pop3Activity;
import org.krakenapps.mime.MimeHeader;
import org.krakenapps.pcap.Protocol;
import org.krakenapps.pcap.decoder.pop3.Pop3Data;
import org.krakenapps.pcap.decoder.pop3.Pop3Decoder;
import org.krakenapps.pcap.decoder.pop3.Pop3Processor;

/**
 * This class utilizes a {@link org.krakenapps.pcap.decoder.pop3.Pop3Decoder} in order
 * to dispatch {@link at.jku.fim.rubanetra.protocol.activity.pop3.Pop3Activity} objects
 * for decoded events.
 * It does not provide any bindings.
 */
public class KrakenPop3Handler extends KrakenBaseProtocol {
    public static final KrakenApplicationProtocolId krakenPop3ProtocolId = new KrakenApplicationProtocolId() {
        @Override
        public Protocol getKrakenApplicationProtocol() {
            return Protocol.POP3;
        }

        @Override
        public String getProtocolId() {
            return Protocol.POP3.name();
        }

        @Override
        public String getName() {
            return "Pop3";
        }
    };

    private final Pop3Decoder krakenPop3Decoder;

    public KrakenPop3Handler() {
        krakenPop3Decoder = new Pop3Decoder();
        krakenPop3Decoder.register(new Pop3Processor() {
            @Override
            public void onReceive(MimeHeader header, Pop3Data data) {
                Pop3Activity act = new Pop3Activity(getCurrentPcapActivity(), Pop3Activity.Type.RECEIVE);
                act.setHeader(header);
                act.setData(data);
                fireNewPartialPop3Activity(act);
            }

            @Override
            public void onCommand(String command) {
                Pop3Activity act = new Pop3Activity(getCurrentPcapActivity(), Pop3Activity.Type.COMMAND);
                act.setCommand(command);
                fireNewPartialPop3Activity(act);
            }

            @Override
            public void onResponse(String response) {
                Pop3Activity act = new Pop3Activity(getCurrentPcapActivity(), Pop3Activity.Type.RESPONSE);
                act.setResponse(response);
                fireNewPartialPop3Activity(act);
            }
        });
    }

    private void fireNewPartialPop3Activity(Pop3Activity act) {
        propertyChangeSupport.firePropertyChange("newPartialPop3Activity", null, act);
    }

    @Override
    public ProtocolId getProtocolId() {
        return krakenPop3ProtocolId;
    }

    /**
     * @return the internally used Pop3 decoder
     */
    public Pop3Decoder getKrakenPop3Decoder() {
        return krakenPop3Decoder;
    }
}
