/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.handler;


import at.jku.fim.rubanetra.config.model.KrakenApplicationProtocolId;
import at.jku.fim.rubanetra.config.model.ProtocolId;
import at.jku.fim.rubanetra.protocol.KrakenBaseProtocol;
import at.jku.fim.rubanetra.protocol.activity.smtp.SmtpActivity;
import at.jku.fim.rubanetra.protocol.activity.smtp.SmtpCommandActivity;
import at.jku.fim.rubanetra.protocol.activity.smtp.SmtpReplyActivity;
import at.jku.fim.rubanetra.protocol.activity.smtp.SmtpSendActivity;
import org.krakenapps.mime.MimeHeader;
import org.krakenapps.pcap.Protocol;
import org.krakenapps.pcap.decoder.smtp.SmtpData;
import org.krakenapps.pcap.decoder.smtp.SmtpDecoder;
import org.krakenapps.pcap.decoder.smtp.SmtpProcessor;

/**
 * Uses a {@link org.krakenapps.pcap.decoder.smtp.SmtpDecoder} to receive decoded
 * SMTP data that is wrapped into appropriate {@link at.jku.fim.rubanetra.protocol.activity.smtp.SmtpActivity}
 * extension instances.
 * This class does not provide any bindings.
 */
public class KrakenSmtpHandler extends KrakenBaseProtocol {
    public static final String NEW_SMTP_SEND_ACTIVITY_PROPERTY_NAME = "newSmtpSendActivity";
    public static final String NEW_SMTP_COMMAND_ACTIVITY_PROPERTY_NAME = "newSmtpCommandActivity";
    public static final String NEW_SMTP_REPLY_ACTIVITY_PROPERTY_NAME = "newSmtpReplyActivity";
    public static final KrakenApplicationProtocolId krakenSmtpProtocolId = new KrakenApplicationProtocolId() {
        private final String protocolId = Protocol.SMTP.name();

        @Override
        public Protocol getKrakenApplicationProtocol() {
            return Protocol.SMTP;
        }

        @Override
        public String getProtocolId() {
            return protocolId;
        }

        @Override
        public String getName() {
            return "Smtp";
        }

        @Override
        public String toString() {
            return getName();
        }
    };

    private final SmtpDecoder krakenSmtpDecoder;

    public KrakenSmtpHandler() {
        krakenSmtpDecoder = new SmtpDecoder();
        krakenSmtpDecoder.register(new SmtpProcessor() {
            @Override
            public void onSend(MimeHeader header, SmtpData data) {
                SmtpActivity act = new SmtpSendActivity(getCurrentPcapActivity(), header, data);
                propertyChangeSupport.firePropertyChange(NEW_SMTP_SEND_ACTIVITY_PROPERTY_NAME, null, act);
            }

            @Override
            public void onCommand(String command, String parameter) {
                SmtpActivity act = new SmtpCommandActivity(getCurrentPcapActivity(), command, parameter);
                propertyChangeSupport.firePropertyChange(NEW_SMTP_COMMAND_ACTIVITY_PROPERTY_NAME, null, act);
            }

            @Override
            public void onReply(int code, String message) {
                SmtpActivity act = new SmtpReplyActivity(getCurrentPcapActivity(), code, message);
                propertyChangeSupport.firePropertyChange(NEW_SMTP_REPLY_ACTIVITY_PROPERTY_NAME, null, act);
            }
        });
    }

    @Override
    public ProtocolId getProtocolId() {
        return krakenSmtpProtocolId;
    }

    /**
     * @return the internally used SMTP decoder
     */
    public SmtpDecoder getKrakenSmtpDecoder() {
        return krakenSmtpDecoder;
    }


}
