/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.handler;

import at.jku.fim.rubanetra.config.model.KrakenApplicationProtocolId;
import at.jku.fim.rubanetra.config.model.ProtocolId;
import at.jku.fim.rubanetra.protocol.KrakenBaseProtocol;
import at.jku.fim.rubanetra.protocol.activity.snmp.Snmpv1Activity;
import at.jku.fim.rubanetra.protocol.activity.snmp.Snmpv2Activity;
import org.krakenapps.pcap.Protocol;
import org.krakenapps.pcap.decoder.snmp.SnmpDecoder;
import org.krakenapps.pcap.decoder.snmp.v1.Pdu;

import java.net.InetSocketAddress;

/**
 * Handles decoded SNMP data by listening to appropriate events that are fired by
 * {@link org.krakenapps.pcap.decoder.snmp.SnmpDecoder} and creates
 * {@link at.jku.fim.rubanetra.protocol.activity.snmp.Snmpv1Activity}
 * and/or {@link at.jku.fim.rubanetra.protocol.activity.snmp.Snmpv2Activity}
 * objects.
 * This class does not provide any forward bindings and does not support
 * SNMPv3 due to lacking decoder support..
 */
public class KrakenSnmpHandler extends KrakenBaseProtocol {
    public static final KrakenApplicationProtocolId krakenSnmpProtocolId = new KrakenApplicationProtocolId() {
        @Override
        public Protocol getKrakenApplicationProtocol() {
            return Protocol.SNMP;
        }

        @Override
        public String getProtocolId() {
            return Protocol.SNMP.name();
        }

        @Override
        public String getName() {
            return "Snmp";
        }
    };
    public static final String PROPERTY_NEW_SNMPV_1_ACTIVITY = "newSnmpv1Activity";
    public static final String PROPERTY_NEW_SNMPV_2_ACTIVITY = "newSnmpv2Activity";
    private final SnmpDecoder krakenSnmpDecoder;

    public KrakenSnmpHandler() {
        krakenSnmpDecoder = new SnmpDecoder();
        krakenSnmpDecoder.register((InetSocketAddress source, InetSocketAddress destination, Pdu pdu) -> {
            Snmpv1Activity act = new Snmpv1Activity(getCurrentPcapActivity(), pdu, source, destination);
            propertyChangeSupport.firePropertyChange(PROPERTY_NEW_SNMPV_1_ACTIVITY, null, act);
        });
        krakenSnmpDecoder.register((InetSocketAddress source, InetSocketAddress destination, org.krakenapps.pcap.decoder.snmp.v2.Pdu pdu) -> {
            Snmpv2Activity act = new Snmpv2Activity(getCurrentPcapActivity(), pdu, source, destination);
            propertyChangeSupport.firePropertyChange(PROPERTY_NEW_SNMPV_2_ACTIVITY, null, act);
        });
        // V3 is not yet implemented by Kraken
    }

    @Override
    public ProtocolId getProtocolId() {
        return krakenSnmpProtocolId;
    }

    /**
     * @return the internally used SNMP decoder
     */
    public SnmpDecoder getKrakenSnmpDecoder() {
        return krakenSnmpDecoder;
    }
}
