/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.mapper;


import at.jku.fim.rubanetra.config.model.KrakenApplicationProtocolId;
import org.krakenapps.pcap.decoder.tcp.TcpProcessor;
import org.krakenapps.pcap.decoder.tcp.TcpProtocolMapper;

import java.util.Set;

/**
 * Extends the Kraken interface used for mapping a transport layer protocol (TCP in this case) to application layer
 * protocol decoders.
 */
public interface KrakenTcpProtocolMapperStrategy extends TcpProtocolMapper, TransportLayerMappingStrategy {
    /**
     * An unmodifiable collection of all registered decoders that are capable of processing TCP payloads.
     *
     * @return an unmodifiable collection of all registered decoders that are capable of processing TCP payloads.
     */
    public abstract Set<TcpProcessor> getTcpProcessors();

    /**
     * Registers a TCP processor for the given application layer protocol.
     *
     * @param processor  the TCP processor to be registered for ...
     * @param protocolId ... the application layer protocol id
     */
    public abstract void register(TcpProcessor processor, KrakenApplicationProtocolId protocolId);
}
