/**
 * This file is part of Rubanetra.
 * Copyright (C) 2013,2014 Stefan Swerk (stefan_rubanetra@swerk.priv.at)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package at.jku.fim.rubanetra.protocol.mapper;


import at.jku.fim.rubanetra.config.model.KrakenApplicationProtocolId;
import org.krakenapps.pcap.decoder.udp.UdpProcessor;
import org.krakenapps.pcap.decoder.udp.UdpProtocolMapper;

import java.util.Set;

/**
 * Extends the Kraken interface used for mapping a transport layer protocol (UDP in this case) to application layer
 * protocol decoders following a certain strategy.
 */
public interface KrakenUdpProtocolMapperStrategy extends UdpProtocolMapper, TransportLayerMappingStrategy {
    /**
     * Registers an UDP processor that is capable of parsing application layer protocol, identified by
     * the protocolId, specific data.
     *
     * @param processor  the UDP processor for a protocol identified by ...
     * @param protocolId the application layer protocol identifier
     */
    public abstract void register(UdpProcessor processor, KrakenApplicationProtocolId protocolId);

    /**
     * Returns the unmodifiable set of all registered UDP processors.
     *
     * @return the unmodifiable set of all registered UDP processors
     */
    public abstract Set<UdpProcessor> getUdpProcessors();
}
